@@ -12,13 +12,13 @@ class PlanRecord(BasePolarion):
     """Object to handle the Polarion WSDL tns6:PlanRecord class
 
     Attributes:
-        item (_WorkItem)
-"""
-    _cls_suds_map = {"item":
-                     {"field_name": "item",
-                      "cls": _WorkItem},
-                     "uri": "_uri",
-                     "_unresolved": "_unresolved"}
+        item (_WorkItem)"""
+
+    _cls_suds_map = {
+        "item": {"field_name": "item", "cls": _WorkItem},
+        "uri": "_uri",
+        "_unresolved": "_unresolved",
+    }
     _obj_client = "builder_client"
     _obj_struct = "tns6:PlanRecord"
 
