@@ -17,17 +17,17 @@ class TimePoint(BasePolarion):
         earliest_planned_start (date)
         time_point_id (string)
         name (string)
-        time (date)
-"""
-    _cls_suds_map = {"closed": "closed",
-                     "description":
-                     {"field_name": "description",
-                      "cls": Text},
-                     "earliest_planned_start": "earliestPlannedStart",
-                     "time_point_id": "id",
-                     "name": "name",
-                     "time": "time",
-                     "uri": "_uri",
-                     "_unresolved": "_unresolved"}
+        time (date)"""
+
+    _cls_suds_map = {
+        "closed": "closed",
+        "description": {"field_name": "description", "cls": Text},
+        "earliest_planned_start": "earliestPlannedStart",
+        "time_point_id": "id",
+        "name": "name",
+        "time": "time",
+        "uri": "_uri",
+        "_unresolved": "_unresolved",
+    }
     _obj_client = "builder_client"
     _obj_struct = "tns5:TimePoint"
